.. statesxt documentation master file, created by
   sphinx-quickstart on Wed Jan 10 16:59:33 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to StateSXT's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   contents/introduction
   contents/quick_start

.. toctree::
   :maxdepth: 2
   :caption: Template

   contents/base
   contents/database
   contents/locators
   contents/pages
   contents/testcases
   contents/utils
   contents/env_template
   contents/gitignore
   contents/poetry-lock
   contents/pyproject-toml
   contents/pytest-ini
   contents/README-md